@@ -175,12 +175,12 @@ void Ambitus::write(Xml& xml) const
       xml.tag("topTpc",     _topTpc);
       xml.tag("bottomPitch",_bottomPitch);
       xml.tag("bottomTpc",  _bottomTpc);
-      if (_topAccid.accidentalType() != Accidental::Type::NONE) {
+      if (_topAccid.accidentalType() != AccidentalType::NONE) {
             xml.stag("topAccidental");
             _topAccid.write(xml);
             xml.etag();
             }
-      if (_bottomAccid.accidentalType() != Accidental::Type::NONE) {
+      if (_bottomAccid.accidentalType() != AccidentalType::NONE) {
             xml.stag("bottomAccidental");
             _bottomAccid.write(xml);
             xml.etag();
@@ -285,18 +285,18 @@ void Ambitus::layout()
             topLine  = relStep(topLine, clf);
             _topPos.setY(topLine * lineDist * 0.5);
             // compute accidental
-            Accidental::Type accidType;
+            AccidentalType accidType;
             // if (13 <= (tpc - key) <= 19) there is no accidental)
             if (_topTpc - int(key) >= 13 && _topTpc - int(key) <= 19)
-                  accidType = Accidental::Type::NONE;
+                  accidType = AccidentalType::NONE;
             else {
                   AccidentalVal accidVal = AccidentalVal( (_topTpc - Tpc::TPC_MIN) / TPC_DELTA_SEMITONE - 2 );
                   accidType = Accidental::value2subtype(accidVal);
-                  if (accidType == Accidental::Type::NONE)
-                        accidType = Accidental::Type::NATURAL;
+                  if (accidType == AccidentalType::NONE)
+                        accidType = AccidentalType::NATURAL;
                   }
             _topAccid.setAccidentalType(accidType);
-            if (accidType != Accidental::Type::NONE)
+            if (accidType != AccidentalType::NONE)
                   _topAccid.layout();
             else
                   _topAccid.setbbox(QRect());
@@ -311,17 +311,17 @@ void Ambitus::layout()
             bottomLine  = relStep(bottomLine, clf);
             _bottomPos.setY(bottomLine * lineDist * 0.5);
             // compute accidental
-            Accidental::Type accidType;
+            AccidentalType accidType;
             if (_bottomTpc - int(key) >= 13 && _bottomTpc - int(key) <= 19)
-                  accidType = Accidental::Type::NONE;
+                  accidType = AccidentalType::NONE;
             else {
                   AccidentalVal accidVal = AccidentalVal( (_bottomTpc - Tpc::TPC_MIN) / TPC_DELTA_SEMITONE - 2 );
                   accidType = Accidental::value2subtype(accidVal);
-                  if (accidType == Accidental::Type::NONE)
-                        accidType = Accidental::Type::NATURAL;
+                  if (accidType == AccidentalType::NONE)
+                        accidType = AccidentalType::NATURAL;
                   }
             _bottomAccid.setAccidentalType(accidType);
-            if (accidType != Accidental::Type::NONE)
+            if (accidType != AccidentalType::NONE)
                   _bottomAccid.layout();
             else
                   _bottomAccid.setbbox(QRect());
@@ -346,9 +346,9 @@ void Ambitus::layout()
       if (collision) {
             // displace bottom accidental (also attempting to 'undercut' flats)
             xAccidOffBottom = xAccidOffTop +
-                  ((_bottomAccid.accidentalType() == Accidental::Type::FLAT
-                        || _bottomAccid.accidentalType() == Accidental::Type::FLAT2
-                        || _bottomAccid.accidentalType() == Accidental::Type::NATURAL)
+                  ((_bottomAccid.accidentalType() == AccidentalType::FLAT
+                        || _bottomAccid.accidentalType() == AccidentalType::FLAT2
+                        || _bottomAccid.accidentalType() == AccidentalType::NATURAL)
                   ? _bottomAccid.width() * 0.5 : _bottomAccid.width());
             }
 
@@ -447,8 +447,8 @@ Space Ambitus::space() const
       qreal _spatium = spatium();
       // reduce left space if there accidentals
       qreal leftSpace = _spatium *
-            ((_topAccid.accidentalType() != Accidental::Type::NONE
-                  || _bottomAccid.accidentalType() != Accidental::Type::NONE)
+            ((_topAccid.accidentalType() != AccidentalType::NONE
+                  || _bottomAccid.accidentalType() != AccidentalType::NONE)
             ? 0.5 : 0.75);
       return Space(leftSpace - bbox().x(), width() + bbox().x() + _spatium * 0.5);
       }
@@ -460,9 +460,9 @@ Space Ambitus::space() const
 void Ambitus::scanElements(void* data, void (*func)(void*, Element*), bool /*all*/)
       {
       func(data, this);
-      if (_topAccid.accidentalType() != Accidental::Type::NONE)
+      if (_topAccid.accidentalType() != AccidentalType::NONE)
             func(data, &_topAccid);
-      if (_bottomAccid.accidentalType() != Accidental::Type::NONE)
+      if (_bottomAccid.accidentalType() != AccidentalType::NONE)
             func(data, &_bottomAccid);
       }
 
