@@ -54,6 +54,7 @@ const ClefInfo ClefInfo::clefTable[] = {
 { "F15ma","F",         4,  2, 47, { 2, 5, 1, 4, 7, 3, 6, 6, 3, 7, 4, 8, 5, 9 }, QT_TRANSLATE_NOOP("clefTable", "Bass clef 15ma"),         StaffGroup::STANDARD  }, // F_15MA
 { "PERC2","percussion",2,  0, 45, { 0, 3,-1, 2, 5, 1, 4, 4, 1, 5, 2, 6, 3, 7 }, QT_TRANSLATE_NOOP("clefTable", "Percussion"),             StaffGroup::PERCUSSION}, // PERC2 placeholder
 { "TAB2", "TAB",       5,  0,  0, { 0, 3,-1, 2, 5, 1, 4, 4, 1, 5, 2, 6, 3, 7 }, QT_TRANSLATE_NOOP("clefTable", "Tablature2"),             StaffGroup::TAB       },
+{ "G8vbp","G",         2,  0, 45, { 0, 3,-1, 2, 5, 1, 4, 4, 1, 5, 2, 6, 3, 7 }, QT_TRANSLATE_NOOP("clefTable", "Treble clef optional 8vb"),StaffGroup::STANDARD }, // G5
       };
 
 
@@ -185,7 +186,7 @@ void Clef::layout()
                   Measure* meas = clefSeg->measure();
                   showClef =                    // show this clef if:
                         // it is not a courtesy clef (not at the end of the last measure of the system)
-                        (meas != meas->system()->lastMeasure()) || (clefSeg->tick() != meas->endTick())
+                        ((meas->system() && meas != meas->system()->lastMeasure())) || (clefSeg->tick() != meas->endTick())
                         // if courtesy clef: show if score has courtesy clefs on
                         || ( score()->styleB(StyleIdx::genCourtesyClef)
                               // AND measure is not at the end of a repeat or of a section
@@ -316,6 +317,10 @@ void Clef::layout1()
                   symbol->setSym(SymId::fClef15ma);
                   yoff = 1.0 * curLineDist;
                   break;
+            case ClefType::G5:                              // G clef on 2nd line
+                  symbol->setSym(SymId::gClef8vbParens);
+                  yoff = 3.0 * curLineDist;
+                  break;
             case ClefType::INVALID:
             case ClefType::MAX:
                   return;
@@ -343,7 +348,7 @@ void Clef::draw(QPainter* painter) const
             return;
       QColor color(curColor());
       foreach(Element* e, elements) {
-            e->setColor(color);
+            e->setColor(color);           //??
             QPointF pt(e->pos());
             painter->translate(pt);
             e->draw(painter);
