@@ -472,14 +472,15 @@ QPointF SLine::linePos(Grip grip, System** sys) const
                   ChordRest* cr;
                   if (grip == Grip::START) {
                         cr = static_cast<ChordRest*>(startElement());
-                        if (cr) {
+                        if (cr && type() == Element::Type::OTTAVA) {
                               // some sources say to center the text over the note head
-                              // some say to start the text just to left of notehead
-                              // our simple compromise - left align
-                              if (cr->durationType() == TDuration::DurationType::V_MEASURE && type() == Element::Type::OTTAVA)
-                                    x = cr->x();                  // center for measure rests
+                              // others say to start the text just to left of notehead
+                              // some say to include accidental, others don't
+                              // our compromise - left align, but account for accidental
+                              if (cr->durationType() == TDuration::DurationType::V_MEASURE)
+                                    x = cr->x();            // center for measure rests
                               else if (cr->space().lw() > 0.0)
-                                    x = -cr->space().lw();        // account for accidentals, etc
+                                    x = -cr->space().lw();  // account for accidentals, etc
                               }
                         }
                   else {
@@ -658,6 +659,8 @@ QPointF SLine::linePos(Grip grip, System** sys) const
 //                  System* s = static_cast<Note*>(startElement())->chord()->segment()->system();
 //                  *sys = s;
                   Element* e = grip == Grip::START ? startElement() : endElement();
+                  if (!e)
+                        return QPointF();
                   System* s = static_cast<Note*>(e)->chord()->segment()->system();
                   *sys = s;
                   // for GLISSANDO returns the position of the anchor note relative to the system
