@@ -624,23 +624,23 @@ int diatonicUpDown(Key k, int pitch, int steps)
       {
       static int ptab[15][7] = {
 //             c  c#   d  d#    e   f  f#   g  g#  a  a#   b
-            { -1,      1,       3,  4,      6,     8,      10 },     // Ces
-            { -1,      1,       3,  5,      6,     8,      10 },     // Ges
-            {  0,      1,       3,  5,      6,     8,      10 },     // Des
-            {  0,      1,       3,  5,      7,     8,      10 },     // As
-            {  0,      2,       3,  5,      7,     8,      10 },     // Es
-            {  0,      2,       3,  5,      7,     9,      10 },     // B
-            {  0,      2,       4,  5,      7,     9,      10 },     // F
+            { -1,      1,       3,  4,      6,     8,      10 },     // Cb Ces
+            { -1,      1,       3,  5,      6,     8,      10 },     // Gb Ges
+            {  0,      1,       3,  5,      6,     8,      10 },     // Db Des
+            {  0,      1,       3,  5,      7,     8,      10 },     // Ab As
+            {  0,      2,       3,  5,      7,     8,      10 },     // Eb Es
+            {  0,      2,       3,  5,      7,     9,      10 },     // Bb B
+            {  0,      2,       4,  5,      7,     9,      10 },     // F  F
 
-            {  0,      2,       4,  5,      7,     9,      11 },     // C
+            {  0,      2,       4,  5,      7,     9,      11 },     // C  C
 
-            {  0,      2,       4,  6,      7,     9,      11 },     // G
-            {  1,      2,       4,  6,      7,     9,      11 },     // D
-            {  1,      2,       4,  6,      8,     9,      11 },     // A
-            {  1,      3,       4,  6,      8,     9,      11 },     // E
-            {  1,      3,       4,  6,      8,    10,      11 },     // H
-            {  1,      3,       5,  6,      8,    10,      11 },     // Fis
-            {  1,      3,       5,  6,      8,    10,      12 },     // Cis
+            {  0,      2,       4,  6,      7,     9,      11 },     // G  G
+            {  1,      2,       4,  6,      7,     9,      11 },     // D  D
+            {  1,      2,       4,  6,      8,     9,      11 },     // A  A
+            {  1,      3,       4,  6,      8,     9,      11 },     // E  E
+            {  1,      3,       4,  6,      8,    10,      11 },     // B  H
+            {  1,      3,       5,  6,      8,    10,      11 },     // F# Fis
+            {  1,      3,       5,  6,      8,    10,      12 },     // C# Cis
             };
 
       int key    = int(k) + 7;
@@ -865,16 +865,19 @@ int relStep(int pitch, int tpc, ClefType clef)
 
 //---------------------------------------------------------
 //   pitch2step
+//   returns one of { 0, 1, 2, 3, 4, 5, 6 }
 //---------------------------------------------------------
 
 int pitch2step(int pitch)
       {
+      //                            C  C# D  D# E  F  F# G  G# A  A# B
       static const char tab[12] = { 0, 0, 1, 1, 2, 3, 3, 4, 4, 5, 5, 6 };
       return tab[pitch%12];
       }
 
 //---------------------------------------------------------
 //   step2pitch
+//   returns one of { 0, 2, 4, 5, 7, 9, 11 }
 //---------------------------------------------------------
 
 int step2pitch(int step)
