@@ -591,6 +591,7 @@ void Debugger::updateElement(Element* el)
                   case Element::Type::MEASURE:          ew = new MeasureView;         break;
                   case Element::Type::CHORD:            ew = new ChordDebug;          break;
                   case Element::Type::NOTE:             ew = new ShowNoteWidget;      break;
+                  case Element::Type::REPEAT_MEASURE:
                   case Element::Type::REST:             ew = new RestView;            break;
                   case Element::Type::CLEF:             ew = new ClefView;            break;
                   case Element::Type::TIMESIG:          ew = new TimeSigView;         break;
@@ -1205,7 +1206,7 @@ void ShowNoteWidget::accidentalClicked()
 RestView::RestView()
    : ShowElementBase()
       {
-      // chort rest
+      // chord rest
       crb.setupUi(addWidget());
       crb.beamMode->addItem("auto");
       crb.beamMode->addItem("beam begin");
@@ -2393,8 +2394,8 @@ void AccidentalView::setElement(Element* e)
       ShowElementBase::setElement(e);
 
       acc.hasBracket->setChecked(s->hasBracket());
-      acc.accAuto->setChecked(s->role() == Accidental::Role::AUTO);
-      acc.accUser->setChecked(s->role() == Accidental::Role::USER);
+      acc.accAuto->setChecked(s->role() == AccidentalRole::AUTO);
+      acc.accUser->setChecked(s->role() == AccidentalRole::USER);
       acc.small->setChecked(s->small());
       }
 
@@ -2473,6 +2474,7 @@ void KeySigView::setElement(Element* e)
       keysig.showCourtesySig->setChecked(ks->showCourtesy());
       keysig.accidentalType->setValue(int(ev.key()));
       keysig.custom->setChecked(ev.custom());
+      keysig.atonal->setChecked(ev.isAtonal());
       keysig.invalid->setChecked(!ev.isValid());
       }
 
