@@ -276,7 +276,7 @@ static void aaamoveTick(Fraction& tick, Fraction& maxtick,
 MusicXmlPart::MusicXmlPart(QString id, QString name)
       : id(id), name(name)
       {
-      // nothing yet
+      octaveShifts.resize(MAX_STAVES);
       }
 
 
@@ -316,6 +316,31 @@ QString MusicXmlPart::toString() const
       return res;
       }
 
+int MusicXmlPart::octaveShift(const int staff, const Fraction f) const
+      {
+      if (staff < 0 || MAX_STAVES <= staff)
+            return 0;
+      if (f < Fraction(0, 1))
+            return 0;
+      return octaveShifts[staff].octaveShift(f);            
+      }
+      
+void MusicXmlPart::addOctaveShift(const int staff, const int shift, const Fraction f)
+      {
+      if (staff < 0 || MAX_STAVES <= staff)
+            return;
+      if (f < Fraction(0, 1))
+            return;
+      octaveShifts[staff].addOctaveShift(shift, f);
+      }
+
+void MusicXmlPart::calcOctaveShifts()
+      {
+      for (int i = 0; i < MAX_STAVES; ++i) {
+            octaveShifts[i].calcOctaveShiftShifts();
+            }
+      }
+
 
 MxmlReaderFirstPass::MxmlReaderFirstPass()
       {
@@ -925,4 +950,51 @@ void MusicXmlInstrList::setInstrument(const QString instr, const Fraction f)
             //(*this)[f] = instr;
       }
 
-}
+// TODO: move to importmxml*.cpp
+      
+int MusicXmlOctaveShiftList::octaveShift(const Fraction f) const
+      {
+      if (empty())
+            return 0;
+      auto i = upper_bound(f);
+      if (i == begin())
+            return 0;
+      --i;
+      return i->second;
+      }
+
+void MusicXmlOctaveShiftList::addOctaveShift(const int shift, const Fraction f)
+      {
+      Q_ASSERT(Fraction(0, 1) <= f);
+               
+      qDebug("addOctaveShift(shift %d f %s)", shift, qPrintable(f.print()));
+      auto i = find(f);
+      if (i == end()) {
+            qDebug("addOctaveShift: not found, inserting");
+            insert({f, shift});
+            }
+      else {
+            qDebug("addOctaveShift: found %d, adding", (*this)[f]);
+            (*this)[f] += shift;
+            qDebug("addOctaveShift: res %d", (*this)[f]);
+            }
+      }
+
+      void MusicXmlOctaveShiftList::calcOctaveShiftShifts()
+      {
+      for (auto i = cbegin(); i != cend(); ++i)
+            qDebug(" [%s : %d]", qPrintable((*i).first.print()), (*i).second);
+
+      // to each MusicXmlOctaveShiftList entry, add the sum of all previous ones
+      int currentShift = 0;
+      for (auto i = begin(); i != end(); ++i) {
+            currentShift += i->second;
+            i->second = currentShift;
+      }
+
+      for (auto i = cbegin(); i != cend(); ++i)
+            qDebug(" [%s : %d]", qPrintable((*i).first.print()), (*i).second);
+
+      }
+
+}
\ No newline at end of file
