@@ -408,32 +408,7 @@ void InspectorBase::resetClicked(int i)
             return;
       QWidget* w   = ii.w;
       w->blockSignals(true);
-
-      if (qobject_cast<QDoubleSpinBox*>(w))
-            static_cast<QDoubleSpinBox*>(w)->setValue(def.toDouble());
-      else if (qobject_cast<QSpinBox*>(w))
-            static_cast<QSpinBox*>(w)->setValue(def.toInt());
-      else if (qobject_cast<QComboBox*>(w)) {
-            int ival = def.toInt();
-            QComboBox* cb = qobject_cast<QComboBox*>(w);
-            if (cb->itemData(0).isValid()) {
-                  for (int i = 0; i < cb->count(); ++i) {
-                        if (cb->itemData(i).toInt() == ival) {
-                              ival = i;
-                              break;
-                              }
-                        }
-                  }
-            cb->setCurrentIndex(ival);
-            }
-      else if (qobject_cast<QCheckBox*>(w))
-            static_cast<QCheckBox*>(w)->setChecked(def.toBool());
-      else if (qobject_cast<QLineEdit*>(w))
-            static_cast<QLineEdit*>(w)->setText(def.toString());
-      else if (qobject_cast<Awl::ColorLabel*>(w))
-            static_cast<Awl::ColorLabel*>(w)->setColor(def.value<QColor>());
-      else
-            qFatal("not supported widget %s", w->metaObject()->className());
+      setValue(ii, def);
       w->blockSignals(false);
 
       valueChanged(i, true);
