@@ -22,6 +22,7 @@
 #include "musescore.h"
 #include "scoreview.h"
 #include "seq.h"
+#include "libmscore/barline.h"
 #include "libmscore/clef.h"
 #include "libmscore/excerpt.h"
 #include "libmscore/instrtemplate.h"
@@ -389,7 +390,7 @@ void MuseScore::editInstrList()
       QList<int> dl;
       int idx2 = 0;
       bool sort = false;
-      for(Staff* staff : dst) {
+      for (Staff* staff : dst) {
             int idx = rootScore->staves().indexOf(staff);
             if (idx == -1)
                   qDebug("staff in dialog(%p) not found in score", staff);
@@ -409,10 +410,62 @@ void MuseScore::editInstrList()
       //
 
       int n = rootScore->nstaves();
+      int curSpan = 0;
       for (int i = 0; i < n; ++i) {
             Staff* staff = rootScore->staff(i);
-            if (staff->barLineSpan() > (n - i))
-                  rootScore->undoChangeBarLineSpan(staff, n - i, 0, (rootScore->staff(n-1)->lines()-1) * 2);
+            int span = staff->barLineSpan();
+            int setSpan = -1;
+
+            // determine if we need to update barline span
+            if (curSpan == 0) {
+                  // no current span; this staff must start a new one
+                  if (span == 0) {
+                        // no span; this staff must have been within a span
+                        // update it to a span of 1
+                        setSpan = 1;
+                        }
+                  else if (span > (n - i)) {
+                        // span too big; staves must have been removed
+                        // reduce span to last staff
+                        setSpan = n - i;
+                        }
+                  else if (span > 1 && staff->barLineTo() > 0) {
+                        // TODO: check if span is still valid
+                        // (true if the last staff is the same as it was before this edit)
+                        // the code here fixes https://musescore.org/en/node/41786
+                        // but by forcing an update,
+                        // we lose custom modifications to staff barLineTo
+                        // at least this happens only for span > 1, and not for Mensurstrich (barLineTo<=0)
+                        setSpan = span;   // force update to pick up new barLineTo value
+                        }
+                  else {
+                        // this staff starts a span
+                        curSpan = span;
+                        }
+                  }
+            else if (span && staff->barLineTo() > 0) {
+                  // within a current span; staff must have span of 0
+                  // except for Mensurstrich (barLineTo<=0)
+                  // for consistency with Barline::endEdit,
+                  // don't special case 1-line staves
+                  rootScore->undoChangeBarLineSpan(staff, 0, 0, (staff->lines() - 1) * 2);
+                  }
+
+            // update barline span if necessary
+            if (setSpan > 0) {
+                  // this staff starts a span
+                  curSpan = setSpan;
+                  // calculate spanFrom and spanTo values
+                  int spanFrom = staff->lines() == 1 ? BARLINE_SPAN_1LINESTAFF_FROM : 0;
+                  int linesTo = rootScore->staff(i + setSpan - 1)->lines();
+                  int spanTo = linesTo == 1 ? BARLINE_SPAN_1LINESTAFF_TO : (linesTo - 1) * 2;
+                  rootScore->undoChangeBarLineSpan(staff, setSpan, spanFrom, spanTo);
+                  }
+
+            // count off one from barline span
+            --curSpan;
+
+            // update brackets
             QList<BracketItem> brackets = staff->brackets();
             int nn = brackets.size();
             for (int ii = 0; ii < nn; ++ii) {
@@ -420,6 +473,7 @@ void MuseScore::editInstrList()
                         rootScore->undoChangeBracketSpan(staff, ii, n - i);
                   }
             }
+
       //
       // there should be at least one measure
       //
