@@ -82,7 +82,7 @@ void TestSpanners::spanners01()
       QVERIFY(msr);
       Segment*    seg   = msr->findSegment(Segment::Type::ChordRest, 0);
       QVERIFY(seg);
-      Chord*      chord = static_cast<Chord*>(seg->element(0));
+      Ms::Chord*      chord = static_cast<Ms::Chord*>(seg->element(0));
       QVERIFY(chord && chord->type() == Element::Type::CHORD);
       Note*       note  = chord->upNote();
       QVERIFY(note);
@@ -98,7 +98,7 @@ void TestSpanners::spanners01()
       QVERIFY(msr);
       seg   = msr->first();
       QVERIFY(seg);
-      chord = static_cast<Chord*>(seg->element(0));   // voice 0 of staff 0
+      chord = static_cast<Ms::Chord*>(seg->element(0));   // voice 0 of staff 0
       QVERIFY(chord && chord->type() == Element::Type::CHORD);
       note  = chord->upNote();
       QVERIFY(note);
@@ -114,7 +114,7 @@ void TestSpanners::spanners01()
       QVERIFY(msr);
       seg   = msr->first();
       QVERIFY(seg);
-      chord = static_cast<Chord*>(seg->element(4));   // voice 0 of staff 1
+      chord = static_cast<Ms::Chord*>(seg->element(4));   // voice 0 of staff 1
       QVERIFY(chord && chord->type() == Element::Type::CHORD);
       note  = chord->upNote();
       QVERIFY(note);
@@ -130,7 +130,7 @@ void TestSpanners::spanners01()
       QVERIFY(msr);
       seg   = msr->first();
       QVERIFY(seg);
-      chord = static_cast<Chord*>(seg->element(0));   // voice 0 of staff 0
+      chord = static_cast<Ms::Chord*>(seg->element(0));   // voice 0 of staff 0
       QVERIFY(chord && chord->type() == Element::Type::CHORD);
       note  = chord->upNote();
       QVERIFY(note);
@@ -146,7 +146,7 @@ void TestSpanners::spanners01()
       QVERIFY(msr);
       seg   = msr->first();
       QVERIFY(seg);
-      chord = static_cast<Chord*>(seg->element(0));   // voice 0 of staff 0
+      chord = static_cast<Ms::Chord*>(seg->element(0));   // voice 0 of staff 0
       QVERIFY(chord && chord->type() == Element::Type::CHORD);
       note  = chord->upNote();
       QVERIFY(note);
@@ -199,7 +199,7 @@ void TestSpanners::spanners03()
       QVERIFY(msr);
       Segment*    seg   = msr->findSegment(Segment::Type::ChordRest, 0);
       QVERIFY(seg);
-      Chord*      chord = static_cast<Chord*>(seg->element(0));
+      Ms::Chord*      chord = static_cast<Ms::Chord*>(seg->element(0));
       QVERIFY(chord && chord->type() == Element::Type::CHORD);
       Note*       note  = chord->upNote();
       QVERIFY(note);
@@ -211,7 +211,7 @@ void TestSpanners::spanners03()
 
       // GLISSANDO FROM AFTER-GRACE TO BEFORE-GRACE OF NEXT CHORD
       // go to last after-grace of chord and drop a glissando on it
-      Chord*      grace = chord->graceNotesAfter().last();
+      Ms::Chord*      grace = chord->graceNotesAfter().last();
       QVERIFY(grace && grace->type() == Element::Type::CHORD);
       note              = grace->upNote();
       QVERIFY(note);
@@ -224,7 +224,7 @@ void TestSpanners::spanners03()
       // go to next chord
       seg               = seg->nextCR(0);
       QVERIFY(seg);
-      chord             = static_cast<Chord*>(seg->element(0));
+      chord             = static_cast<Ms::Chord*>(seg->element(0));
       QVERIFY(chord && chord->type() == Element::Type::CHORD);
       note              = chord->upNote();
       QVERIFY(note);
@@ -237,7 +237,7 @@ void TestSpanners::spanners03()
       // go to next chord
       seg               = seg->nextCR(0);
       QVERIFY(seg);
-      chord             = static_cast<Chord*>(seg->element(0));
+      chord             = static_cast<Ms::Chord*>(seg->element(0));
       QVERIFY(chord && chord->type() == Element::Type::CHORD);
       // go to its last before-grace note
       grace             = chord->graceNotesBefore().last();
@@ -335,7 +335,7 @@ void TestSpanners::spanners06()
       QVERIFY(msr);
       Segment*    seg   = msr->findSegment(Segment::Type::ChordRest, 0);
       QVERIFY(seg);
-      Chord*      chord = static_cast<Chord*>(seg->element(0));
+      Ms::Chord*      chord = static_cast<Ms::Chord*>(seg->element(0));
       QVERIFY(chord && chord->type() == Element::Type::CHORD);
       Note*       note  = chord->upNote();
       QVERIFY(note);
@@ -368,7 +368,7 @@ void TestSpanners::spanners07()
       QVERIFY(msr);
       Segment*    seg   = msr->findSegment(Segment::Type::ChordRest, 0);
       QVERIFY(seg);
-      Chord*      chord = static_cast<Chord*>(seg->element(0));
+      Ms::Chord*      chord = static_cast<Ms::Chord*>(seg->element(0));
       QVERIFY(chord && chord->type() == Element::Type::CHORD);
       Note*       note  = chord->upNote();
       QVERIFY(note);
@@ -403,7 +403,7 @@ void TestSpanners::spanners08()
       QVERIFY(msr);
       Segment*    seg   = msr->findSegment(Segment::Type::ChordRest, 0);
       QVERIFY(seg);
-      Chord*      chord = static_cast<Chord*>(seg->element(0));
+      Ms::Chord*      chord = static_cast<Ms::Chord*>(seg->element(0));
       QVERIFY(chord && chord->type() == Element::Type::CHORD);
       QVERIFY(chord->lyricsList().size() > 0);
       Lyrics*     lyr   = chord->lyrics(0);
